[master] Imported from libpng-1.4.4beta05.tar
diff --git a/ANNOUNCE b/ANNOUNCE
index a9dcaf2..14ff8b4 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -50,7 +50,6 @@
   Updated the read macros and functions from 1.5.0beta38.
 
 version 1.4.4beta05 [August 3, 2010]
-  Updated projects/visualc71 so it can find scripts/pnglibconf.h
 
 Send comments/corrections/commendations to glennrp at users.sourceforge.net
 or to png-mng-implement at lists.sf.net (subscription required; visit
diff --git a/CHANGES b/CHANGES
index 806acdf..c3c676e 100644
--- a/CHANGES
+++ b/CHANGES
@@ -2634,7 +2634,6 @@
   Updated the read macros and functions from 1.5.0beta38.
 
 version 1.4.4beta05 [August 3, 2010]
-  Updated projects/visualc71 so it can find scripts/pnglibconf.h
 
 Send comments/corrections/commendations to glennrp at users.sourceforge.net
 or to png-mng-implement at lists.sf.net (subscription required; visit
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 0683755..9323b22 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -213,7 +213,7 @@
 # SET UP LINKS
 if(PNG_SHARED)
   set_target_properties(${PNG_LIB_NAME} PROPERTIES
-#   VERSION 14.${PNGLIB_RELEASE}.1.4.4beta04
+#   VERSION 14.${PNGLIB_RELEASE}.1.4.4beta05
     VERSION 14.${PNGLIB_RELEASE}.0
     SOVERSION 14
     CLEAN_DIRECT_OUTPUT 1)
diff --git a/INSTALL b/INSTALL
index 6d544db..953f670 100644
--- a/INSTALL
+++ b/INSTALL
@@ -1,5 +1,5 @@
 
-Installing libpng version 1.4.4beta04 - July 24, 2010
+Installing libpng version 1.4.4beta05 - August 3, 2010
 
 On Unix/Linux and similar systems, you can simply type
 
@@ -46,7 +46,7 @@
 correspond to the version of zlib that's installed.
 
 You can rename the directories that you downloaded (they
-might be called "libpng-1.4.4beta04" or "libpng14" and "zlib-1.2.3"
+might be called "libpng-1.4.4beta05" or "libpng14" and "zlib-1.2.3"
 or "zlib123") so that you have directories called "zlib" and "libpng".
 
 Your directory structure should look like this:
diff --git a/LICENSE b/LICENSE
index a4c7e62..135b0eb 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.4.4beta04, July 24, 2010, are
+libpng versions 1.2.6, August 15, 2004, through 1.4.4beta05, August 3, 2010, are
 Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-July 24, 2010
+August 3, 2010
diff --git a/Makefile.am b/Makefile.am
index 8635588..86b15d1 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -72,7 +72,7 @@
 	${srcdir}/contrib/pngsuite/* \
 	${srcdir}/contrib/visupng/* \
 	$(TESTS) \
-	example.c libpng-1.4.4beta04.txt
+	example.c libpng-1.4.4beta05.txt
 
 CLEANFILES= pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
 libpng.sym
diff --git a/Makefile.in b/Makefile.in
index 57488e3..16b16c4 100644
--- a/Makefile.in
+++ b/Makefile.in
@@ -332,7 +332,7 @@
 	${srcdir}/contrib/pngsuite/* \
 	${srcdir}/contrib/visupng/* \
 	$(TESTS) \
-	example.c libpng-1.4.4beta04.txt
+	example.c libpng-1.4.4beta05.txt
 
 CLEANFILES = pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
 libpng.sym
diff --git a/README b/README
index 8570d69..e1f0587 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.4.4beta04 - July 24, 2010 (shared library 14.0)
+README for libpng version 1.4.4beta05 - August 3, 2010 (shared library 14.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
@@ -185,9 +185,9 @@
        makefile.std     =>  Generic UNIX makefile (cc, creates static
                             libpng.a)
        makefile.elf     =>  Linux/ELF makefile symbol versioning,
-                            (gcc, creates libpng14.so.14.1.4.4beta04)
+                            (gcc, creates libpng14.so.14.1.4.4beta05)
        makefile.linux   =>  Linux/ELF makefile
-                            (gcc, creates libpng14.so.14.1.4.4beta04)
+                            (gcc, creates libpng14.so.14.1.4.4beta05)
        makefile.gcc     =>  Generic makefile (gcc, creates static libpng.a)
        makefile.knr     =>  Archaic UNIX Makefile that converts files with
                             ansi2knr (Requires ansi2knr.c from
@@ -209,12 +209,12 @@
        makefile.openbsd =>  OpenBSD makefile
        makefile.sgi     =>  Silicon Graphics IRIX (cc, creates static lib)
        makefile.sggcc   =>  Silicon Graphics
-                            (gcc, creates libpng14.so.14.1.4.4beta04)
+                            (gcc, creates libpng14.so.14.1.4.4beta05)
        makefile.sunos   =>  Sun makefile
        makefile.solaris =>  Solaris 2.X makefile
-                            (gcc, creates libpng14.so.14.1.4.4beta04)
+                            (gcc, creates libpng14.so.14.1.4.4beta05)
        makefile.so9     =>  Solaris 9 makefile
-                            (gcc, creates libpng14.so.14.1.4.4beta04)
+                            (gcc, creates libpng14.so.14.1.4.4beta05)
        makefile.32sunu  =>  Sun Ultra 32-bit makefile
        makefile.64sunu  =>  Sun Ultra 64-bit makefile
        makefile.sco     =>  For SCO OSr5  ELF and Unixware 7 with Native cc
diff --git a/configure b/configure
index ae582f1..a665940 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.65 for libpng 1.4.4beta04.
+# Generated by GNU Autoconf 2.65 for libpng 1.4.4beta05.
 #
 # Report bugs to <png-mng-implement@lists.sourceforge.net>.
 #
@@ -701,8 +701,8 @@
 # Identity of this package.
 PACKAGE_NAME='libpng'
 PACKAGE_TARNAME='libpng'
-PACKAGE_VERSION='1.4.4beta04'
-PACKAGE_STRING='libpng 1.4.4beta04'
+PACKAGE_VERSION='1.4.4beta05'
+PACKAGE_STRING='libpng 1.4.4beta05'
 PACKAGE_BUGREPORT='png-mng-implement@lists.sourceforge.net'
 PACKAGE_URL=''
 
@@ -1432,7 +1432,7 @@
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures libpng 1.4.4beta04 to adapt to many kinds of systems.
+\`configure' configures libpng 1.4.4beta05 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1502,7 +1502,7 @@
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of libpng 1.4.4beta04:";;
+     short | recursive ) echo "Configuration of libpng 1.4.4beta05:";;
    esac
   cat <<\_ACEOF
 
@@ -1607,7 +1607,7 @@
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-libpng configure 1.4.4beta04
+libpng configure 1.4.4beta05
 generated by GNU Autoconf 2.65
 
 Copyright (C) 2009 Free Software Foundation, Inc.
@@ -2032,7 +2032,7 @@
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by libpng $as_me 1.4.4beta04, which was
+It was created by libpng $as_me 1.4.4beta05, which was
 generated by GNU Autoconf 2.65.  Invocation command line was
 
   $ $0 $@
@@ -2840,7 +2840,7 @@
 
 # Define the identity of the package.
  PACKAGE='libpng'
- VERSION='1.4.4beta04'
+ VERSION='1.4.4beta05'
 
 
 cat >>confdefs.h <<_ACEOF
@@ -2904,7 +2904,7 @@
 
 
 
-PNGLIB_VERSION=1.4.4beta04
+PNGLIB_VERSION=1.4.4beta05
 PNGLIB_MAJOR=1
 PNGLIB_MINOR=4
 PNGLIB_RELEASE=4
@@ -12032,7 +12032,7 @@
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by libpng $as_me 1.4.4beta04, which was
+This file was extended by libpng $as_me 1.4.4beta05, which was
 generated by GNU Autoconf 2.65.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
@@ -12098,7 +12098,7 @@
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
-libpng config.status 1.4.4beta04
+libpng config.status 1.4.4beta05
 configured by $0, generated by GNU Autoconf 2.65,
   with options \\"\$ac_cs_config\\"
 
diff --git a/configure.ac b/configure.ac
index d083d81..d613443 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,12 +18,12 @@
 
 dnl Version number stuff here:
 
-AC_INIT([libpng], [1.4.4beta04], [png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng], [1.4.4beta05], [png-mng-implement@lists.sourceforge.net])
 AM_INIT_AUTOMAKE
 dnl stop configure from automagically running automake
 AM_MAINTAINER_MODE
 
-PNGLIB_VERSION=1.4.4beta04
+PNGLIB_VERSION=1.4.4beta05
 PNGLIB_MAJOR=1
 PNGLIB_MINOR=4
 PNGLIB_RELEASE=4
diff --git a/libpng-1.4.4beta04.txt b/libpng-1.4.4beta05.txt
similarity index 99%
rename from libpng-1.4.4beta04.txt
rename to libpng-1.4.4beta05.txt
index eabc3c0..468aa2f 100644
--- a/libpng-1.4.4beta04.txt
+++ b/libpng-1.4.4beta05.txt
@@ -1,6 +1,6 @@
 libpng.txt - A description on how to use and modify libpng
 
- libpng version 1.4.4beta04 - July 24, 2010
+ libpng version 1.4.4beta05 - August 3, 2010
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2010 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.4.4beta04 - July 24, 2010
+ libpng versions 0.97, January 1998, through 1.4.4beta05 - August 3, 2010
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2010 Glenn Randers-Pehrson
 
@@ -903,7 +903,7 @@
 As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
 added.  It expands the sample depth without changing tRNS to alpha.
 
-As of libpng version 1.4.4beta04, not all possible expansions are supported.
+As of libpng version 1.4.4beta05, not all possible expansions are supported.
 
 In the following table, the 01 means grayscale with depth<8, 31 means
 indexed with depth<8, other numerals represent the color type, "T" means
@@ -3297,13 +3297,13 @@
 
 XIII. Y2K Compliance in libpng
 
-July 24, 2010
+August 3, 2010
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.4.4beta04 are Y2K compliant.  It is my belief that earlier
+upward through 1.4.4beta05 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has three year fields.  One is a 2-byte unsigned integer that
diff --git a/libpng.3 b/libpng.3
index c7b4253..ea08c34 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "July 24, 2010"
+.TH LIBPNG 3 "August 3, 2010"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.4.4beta04
+libpng \- Portable Network Graphics (PNG) Reference Library 1.4.4beta05
 .SH SYNOPSIS
 \fI\fB
 
@@ -785,7 +785,7 @@
 .SH LIBPNG.TXT
 libpng.txt - A description on how to use and modify libpng
 
- libpng version 1.4.4beta04 - July 24, 2010
+ libpng version 1.4.4beta05 - August 3, 2010
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2010 Glenn Randers-Pehrson
@@ -796,7 +796,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.4.4beta04 - July 24, 2010
+ libpng versions 0.97, January 1998, through 1.4.4beta05 - August 3, 2010
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2010 Glenn Randers-Pehrson
 
@@ -1688,7 +1688,7 @@
 As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
 added.  It expands the sample depth without changing tRNS to alpha.
 
-As of libpng version 1.4.4beta04, not all possible expansions are supported.
+As of libpng version 1.4.4beta05, not all possible expansions are supported.
 
 In the following table, the 01 means grayscale with depth<8, 31 means
 indexed with depth<8, other numerals represent the color type, "T" means
@@ -4082,13 +4082,13 @@
 
 .SH XIII. Y2K Compliance in libpng
 
-July 24, 2010
+August 3, 2010
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.4.4beta04 are Y2K compliant.  It is my belief that earlier
+upward through 1.4.4beta05 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has three year fields.  One is a 2-byte unsigned integer that
@@ -4272,7 +4272,7 @@
  1.4.3beta01-05      14    10403  14.so.14.3[.0]
  1.4.3rc01-03        14    10403  14.so.14.3[.0]
  1.4.3               14    10403  14.so.14.3[.0]
- 1.4.4beta01-04      14    10404  14.so.14.4[.0]
+ 1.4.4beta01-05      14    10404  14.so.14.4[.0]
 
 Henceforth the source version will match the shared-library minor
 and patch numbers; the shared-library major version number will be
@@ -4328,7 +4328,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.4.4beta04 - July 24, 2010:
+Libpng version 1.4.4beta05 - August 3, 2010:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -4351,7 +4351,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.4.4beta04, July 24, 2010, are
+libpng versions 1.2.6, August 15, 2004, through 1.4.4beta05, August 3, 2010, are
 Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -4450,7 +4450,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-July 24, 2010
+August 3, 2010
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index 2cda7bd..aaf1c1c 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "July 24, 2010"
+.TH LIBPNGPF 3 "August 3, 2010"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.4.4beta04
+libpng \- Portable Network Graphics (PNG) Reference Library 1.4.4beta05
 (private functions)
 .SH SYNOPSIS
 \fB#include <png.h>\fP
diff --git a/png.5 b/png.5
index 63d4ba1..c37a91a 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "July 24, 2010"
+.TH PNG 5 "August 3, 2010"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/png.c b/png.c
index 06d60b9..5dab719 100644
--- a/png.c
+++ b/png.c
@@ -17,7 +17,7 @@
 #include "pngpriv.h"
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_4_4beta04 Your_png_h_is_not_version_1_4_4beta04;
+typedef version_1_4_4beta05 Your_png_h_is_not_version_1_4_4beta05;
 
 /* Version information for C files.  This had better match the version
  * string defined in png.h.
@@ -551,13 +551,13 @@
 #else
 #ifdef __STDC__
    return ((png_charp) PNG_STRING_NEWLINE \
-     "libpng version 1.4.4beta04 - July 31, 2010" PNG_STRING_NEWLINE \
+     "libpng version 1.4.4beta05 - August 3, 2010" PNG_STRING_NEWLINE \
      "Copyright (c) 1998-2010 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
      "Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
      "Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
      PNG_STRING_NEWLINE);
 #else
-      return ((png_charp) "libpng version 1.4.4beta04 - July 31, 2010\
+      return ((png_charp) "libpng version 1.4.4beta05 - August 3, 2010\
       Copyright (c) 1998-2010 Glenn Randers-Pehrson\
       Copyright (c) 1996-1997 Andreas Dilger\
       Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.");
diff --git a/pngconf.h b/pngconf.h
index 0cfe346..4ecb584 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
 
 /* pngconf.h - machine configurable file for libpng
  *
- * libpng version 1.4.4beta04 - July 24, 2010
+ * libpng version 1.4.4beta05 - August 3, 2010
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngpriv.h b/pngpriv.h
index eb31f07..2079b29 100644
--- a/pngpriv.h
+++ b/pngpriv.h
@@ -1,7 +1,7 @@
 
 /* pngpriv.h - private declarations for use inside libpng
  *
- * libpng version 1.4.4beta04 - July 24, 2010
+ * libpng version 1.4.4beta05 - August 3, 2010
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index a72ed04..7d5dd54 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1627,4 +1627,4 @@
 }
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_4_4beta04 your_png_h_is_not_version_1_4_4beta04;
+typedef version_1_4_4beta05 your_png_h_is_not_version_1_4_4beta05;
diff --git a/projects/visualc71/libpng.vcproj b/projects/visualc71/libpng.vcproj
index e08346b..ce03e68 100644
--- a/projects/visualc71/libpng.vcproj
+++ b/projects/visualc71/libpng.vcproj
@@ -17,7 +17,7 @@
 			<Tool

 				Name="VCCLCompilerTool"

 				InlineFunctionExpansion="1"

-				AdditionalIncludeDirectories="..\..;..\..\scripts;..\..\..\zlib"

+				AdditionalIncludeDirectories="..\..;..\..\..\zlib"

 				PreprocessorDefinitions="WIN32;NDEBUG;PNG_BUILD_DLL;ZLIB_DLL;_CRT_SECURE_NO_WARNINGS"

 				StringPooling="TRUE"

 				RuntimeLibrary="2"

@@ -45,7 +45,7 @@
 				Name="VCResourceCompilerTool"

 				PreprocessorDefinitions="NDEBUG"

 				Culture="1033"

-				AdditionalIncludeDirectories="..\..;..\..\scripts;..\..\..\zlib;$(IntDir)"/>

+				AdditionalIncludeDirectories="..\..;..\..\..\zlib;$(IntDir)"/>

 			<Tool

 				Name="VCWebServiceProxyGeneratorTool"/>

 			<Tool

@@ -65,7 +65,7 @@
 			<Tool

 				Name="VCCLCompilerTool"

 				Optimization="0"

-				AdditionalIncludeDirectories="..\..;..\..\scripts;..\..\..\zlib"

+				AdditionalIncludeDirectories="..\..;..\..\..\zlib"

 				PreprocessorDefinitions="WIN32;_DEBUG;DEBUG;PNG_DEBUG=1;PNG_BUILD_DLL;ZLIB_DLL;_CRT_SECURE_NO_WARNINGS"

 				BasicRuntimeChecks="3"

 				RuntimeLibrary="3"

@@ -93,7 +93,7 @@
 				Name="VCResourceCompilerTool"

 				PreprocessorDefinitions="_DEBUG,PNG_DEBUG=1"

 				Culture="1033"

-				AdditionalIncludeDirectories="..\..;..\..\scripts;..\..\..\zlib;$(IntDir)"/>

+				AdditionalIncludeDirectories="..\..;..\..\..\zlib;$(IntDir)"/>

 			<Tool

 				Name="VCWebServiceProxyGeneratorTool"/>

 			<Tool

@@ -113,8 +113,8 @@
 			<Tool

 				Name="VCCLCompilerTool"

 				InlineFunctionExpansion="1"

-				AdditionalIncludeDirectories="..\..;..\..\scripts;..\..\..\zlib"

-				PreprocessorDefinitions="WIN32;NDEBUG;PNG_BUILD_DLL;ZLIB_DLL;PNGAPI=__stdcall;PNG_NO_MODULEDEF;PNG_LIBPNG_SPECIALBUILD;PNG_USER_PRIVATEBUILD;_CRT_SECURE_NO_WARNINGS"

+				AdditionalIncludeDirectories="..\..;..\..\..\zlib"

+				PreprocessorDefinitions="WIN32;NDEBUG;PNG_BUILD_DLL;ZLIB_DLL;PNGAPI=__stdcall;PNG_NO_MODULEDEF;PNG_LIBPNG_SPECIALBUILD;_CRT_SECURE_NO_WARNINGS"

 				StringPooling="TRUE"

 				RuntimeLibrary="2"

 				EnableFunctionLevelLinking="TRUE"

@@ -141,7 +141,7 @@
 				AdditionalOptions="/d PNG_NO_PEDANTIC_WARNINGS /d PNG_LIBPNG_DLLFNAME_POSTFIX=&quot;&quot;&quot;&quot;VB&quot;&quot;&quot;&quot; /d PNG_LIBPNG_SPECIALBUILD=&quot;&quot;&quot;&quot;__stdcall calling convention used for exported functions&quot;&quot;&quot;&quot;"

 				PreprocessorDefinitions="NDEBUG"

 				Culture="1033"

-				AdditionalIncludeDirectories="..\..;..\..\scripts;..\..\..\zlib;$(IntDir)"/>

+				AdditionalIncludeDirectories="..\..;..\..\..\zlib;$(IntDir)"/>

 			<Tool

 				Name="VCWebServiceProxyGeneratorTool"/>

 			<Tool

@@ -161,10 +161,10 @@
 			<Tool

 				Name="VCCLCompilerTool"

 				InlineFunctionExpansion="1"

-				AdditionalIncludeDirectories="..\..;..\..\scripts;..\..\..\zlib"

+				AdditionalIncludeDirectories="..\..;..\..\..\zlib"

 				PreprocessorDefinitions="WIN32;NDEBUG;_CRT_SECURE_NO_WARNINGS"

 				StringPooling="TRUE"

-				RuntimeLibrary="0"

+				RuntimeLibrary="2"

 				EnableFunctionLevelLinking="TRUE"

 				UsePrecompiledHeader="3"

 				PrecompiledHeaderThrough="png.h"

@@ -202,10 +202,10 @@
 			<Tool

 				Name="VCCLCompilerTool"

 				Optimization="0"

-				AdditionalIncludeDirectories="..\..;..\..\scripts;..\..\..\zlib"

+				AdditionalIncludeDirectories="..\..;..\..\..\zlib"

 				PreprocessorDefinitions="WIN32;_DEBUG;DEBUG;PNG_DEBUG=1;_CRT_SECURE_NO_WARNINGS"

 				BasicRuntimeChecks="3"

-				RuntimeLibrary="1"

+				RuntimeLibrary="3"

 				UsePrecompiledHeader="3"

 				PrecompiledHeaderThrough="png.h"

 				WarningLevel="3"

diff --git a/projects/visualc71/pngtest.vcproj b/projects/visualc71/pngtest.vcproj
index 01a3402..a59585e 100644
--- a/projects/visualc71/pngtest.vcproj
+++ b/projects/visualc71/pngtest.vcproj
@@ -17,7 +17,7 @@
 			<Tool

 				Name="VCCLCompilerTool"

 				InlineFunctionExpansion="1"

-				AdditionalIncludeDirectories="..\..\scripts;..\..\..\zlib"

+				AdditionalIncludeDirectories="..\..\..\zlib"

 				PreprocessorDefinitions="WIN32;NDEBUG;PNG_DLL;PNG_NO_STDIO;_CRT_SECURE_NO_WARNINGS"

 				StringPooling="TRUE"

 				RuntimeLibrary="2"

@@ -64,7 +64,7 @@
 			<Tool

 				Name="VCCLCompilerTool"

 				Optimization="0"

-				AdditionalIncludeDirectories="..\..\scripts;..\..\..\zlib"

+				AdditionalIncludeDirectories="..\..\..\zlib"

 				PreprocessorDefinitions="WIN32;_DEBUG;PNG_DLL;PNG_NO_STDIO;_CRT_SECURE_NO_WARNINGS"

 				BasicRuntimeChecks="3"

 				RuntimeLibrary="3"

@@ -112,8 +112,8 @@
 			<Tool

 				Name="VCCLCompilerTool"

 				InlineFunctionExpansion="1"

-				AdditionalIncludeDirectories="..\..\scripts;..\..\..\zlib"

-				PreprocessorDefinitions="WIN32;NDEBUG;PNG_DLL;PNG_NO_STDIO;PNGAPI=__stdcall;PNG_USER_PRIVATEBUILD;_CRT_SECURE_NO_WARNINGS"

+				AdditionalIncludeDirectories="..\..\..\zlib"

+				PreprocessorDefinitions="WIN32;NDEBUG;PNG_DLL;PNG_NO_STDIO;PNGAPI=__stdcall;_CRT_SECURE_NO_WARNINGS"

 				StringPooling="TRUE"

 				RuntimeLibrary="2"

 				EnableFunctionLevelLinking="TRUE"

@@ -162,10 +162,10 @@
 			<Tool

 				Name="VCCLCompilerTool"

 				InlineFunctionExpansion="1"

-				AdditionalIncludeDirectories="..\..\scripts;..\..\..\zlib"

+				AdditionalIncludeDirectories="..\..\..\zlib"

 				PreprocessorDefinitions="WIN32;_DEBUG;_CRT_SECURE_NO_WARNINGS"

 				StringPooling="TRUE"

-				RuntimeLibrary="0"

+				RuntimeLibrary="2"

 				EnableFunctionLevelLinking="TRUE"

 				WarningLevel="3"

 				CompileAs="0"/>

@@ -210,10 +210,10 @@
 			<Tool

 				Name="VCCLCompilerTool"

 				Optimization="0"

-				AdditionalIncludeDirectories="..\..\scripts;..\..\..\zlib"

+				AdditionalIncludeDirectories="..\..\..\zlib"

 				PreprocessorDefinitions="WIN32;_DEBUG;_CRT_SECURE_NO_WARNINGS"

 				BasicRuntimeChecks="3"

-				RuntimeLibrary="1"

+				RuntimeLibrary="3"

 				WarningLevel="3"

 				DebugInformationFormat="4"

 				CompileAs="0"/>

diff --git a/projects/visualc71/zlib.vcproj b/projects/visualc71/zlib.vcproj
index 614b869..23e0ac5 100644
--- a/projects/visualc71/zlib.vcproj
+++ b/projects/visualc71/zlib.vcproj
@@ -17,7 +17,7 @@
 				Name="VCCLCompilerTool"

 				InlineFunctionExpansion="1"

 				AdditionalIncludeDirectories="..\..\..\zlib"

-				PreprocessorDefinitions="WIN32;NDEBUG;_CRT_SECURE_NO_WARNINGS;_CRT_NONSTDC_NO_WARNINGS"

+				PreprocessorDefinitions="WIN32;NDEBUG;_CRT_SECURE_NO_WARNINGS"

 				StringPooling="TRUE"

 				RuntimeLibrary="2"

 				EnableFunctionLevelLinking="TRUE"

@@ -62,7 +62,7 @@
 				Name="VCCLCompilerTool"

 				Optimization="0"

 				AdditionalIncludeDirectories="..\..\..\zlib"

-				PreprocessorDefinitions="WIN32;_DEBUG;_CRT_SECURE_NO_WARNINGS;_CRT_NONSTDC_NO_WARNINGS"

+				PreprocessorDefinitions="WIN32;_DEBUG;_CRT_SECURE_NO_WARNINGS"

 				BasicRuntimeChecks="3"

 				RuntimeLibrary="3"

 				WarningLevel="3"

@@ -107,9 +107,9 @@
 				Name="VCCLCompilerTool"

 				InlineFunctionExpansion="1"

 				AdditionalIncludeDirectories="..\..\..\zlib"

-				PreprocessorDefinitions="WIN32;NDEBUG;_CRT_SECURE_NO_WARNINGS;_CRT_NONSTDC_NO_WARNINGS"

+				PreprocessorDefinitions="WIN32;NDEBUG;_CRT_SECURE_NO_WARNINGS"

 				StringPooling="TRUE"

-				RuntimeLibrary="0"

+				RuntimeLibrary="2"

 				EnableFunctionLevelLinking="TRUE"

 				WarningLevel="3"

 				CompileAs="1"/>

@@ -146,9 +146,9 @@
 				Name="VCCLCompilerTool"

 				Optimization="0"

 				AdditionalIncludeDirectories="..\..\..\zlib"

-				PreprocessorDefinitions="WIN32;_DEBUG;_CRT_SECURE_NO_WARNINGS;_CRT_NONSTDC_NO_WARNINGS"

+				PreprocessorDefinitions="WIN32;_DEBUG;_CRT_SECURE_NO_WARNINGS"

 				BasicRuntimeChecks="3"

-				RuntimeLibrary="1"

+				RuntimeLibrary="3"

 				WarningLevel="3"

 				DebugInformationFormat="4"

 				CompileAs="1"/>

@@ -196,16 +196,7 @@
 				RelativePath="..\..\..\zlib\deflate.c">

 			</File>

 			<File

-				RelativePath="..\..\..\zlib\gzlib.c">

-			</File>

-			<File

-				RelativePath="..\..\..\zlib\gzclose.c">

-			</File>

-			<File

-				RelativePath="..\..\..\zlib\gzread.c">

-			</File>

-			<File

-				RelativePath="..\..\..\zlib\gzwrite.c">

+				RelativePath="..\..\..\zlib\gzio.c">

 			</File>

 			<File

 				RelativePath="..\..\..\zlib\infback.c">

diff --git a/scripts/README.txt b/scripts/README.txt
index 98550de..5be01ce 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,8 +1,8 @@
 
-Makefiles for  libpng version 1.4.4beta04 - July 24, 2010
+Makefiles for  libpng version 1.4.4beta05 - August 3, 2010
 
  makefile.linux    =>  Linux/ELF makefile
-                       (gcc, creates libpng14.so.14.1.4.4beta04)
+                       (gcc, creates libpng14.so.14.1.4.4beta05)
  makefile.gcc      =>  Generic makefile (gcc, creates static libpng.a)
  makefile.knr      =>  Archaic UNIX Makefile that converts files with
                        ansi2knr (Requires ansi2knr.c from
@@ -20,7 +20,7 @@
  makefile.dec      =>  DEC Alpha UNIX makefile
  makefile.dj2      =>  DJGPP 2 makefile
  makefile.elf      =>  Linux/ELF makefile symbol versioning,
-                       (gcc, creates libpng14.so.14.1.4.4beta04)
+                       (gcc, creates libpng14.so.14.1.4.4beta05)
  makefile.freebsd  =>  FreeBSD makefile
  makefile.gcc      =>  Generic gcc makefile
  makefile.hpgcc    =>  HPUX makefile using gcc
@@ -36,12 +36,12 @@
  makefile.os2      =>  OS/2 Makefile (gcc and emx, requires pngos2.def)
  makefile.sco      =>  For SCO OSr5  ELF and Unixware 7 with Native cc
  makefile.sggcc    =>  Silicon Graphics (gcc,
-                       creates libpng14.so.14.1.4.4beta04)
+                       creates libpng14.so.14.1.4.4beta05)
  makefile.sgi      =>  Silicon Graphics IRIX makefile (cc, creates static lib)
  makefile.solaris  =>  Solaris 2.X makefile (gcc,
-                       creates libpng14.so.14.1.4.4beta04)
+                       creates libpng14.so.14.1.4.4beta05)
  makefile.so9      =>  Solaris 9 makefile (gcc,
-                       creates libpng14.so.14.1.4.4beta04)
+                       creates libpng14.so.14.1.4.4beta05)
  makefile.std      =>  Generic UNIX makefile (cc, creates static libpng.a)
  makefile.sunos    =>  Sun makefile
  makefile.32sunu   =>  Sun Ultra 32-bit makefile
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index e766b51..378cc85 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
 
 # Modeled after libxml-config.
 
-version=1.4.4beta04
+version=1.4.4beta05
 prefix=""
 libdir=""
 libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index 8e18a11..1e0233d 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@
 
 Name: libpng
 Description: Loads and saves PNG files
-Version: 1.4.4beta04
+Version: 1.4.4beta05
 Libs: -L${libdir} -lpng14
 Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index a779275..a78f9ae 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@
 
 LIB=	png14
 SHLIB_MAJOR=	0
-SHLIB_MINOR=	1.4.4beta04
+SHLIB_MINOR=	1.4.4beta05
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index aa8fa7a..5e5e494 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@
 
 LIB=	png
 SHLIB_MAJOR=	3
-SHLIB_MINOR=	1.4.4beta04
+SHLIB_MINOR=	1.4.4beta05
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index 3e673b0..876b98f 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@
 MANDIR= ${PREFIX}/man/cat
 
 SHLIB_MAJOR=	0
-SHLIB_MINOR=	1.4.4beta04
+SHLIB_MINOR=	1.4.4beta05
 
 LIB=	png
 SRCS=	png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/png32ce.def b/scripts/png32ce.def
index e8a19f2..a105990 100644
--- a/scripts/png32ce.def
+++ b/scripts/png32ce.def
@@ -15,7 +15,7 @@
  png_get_int_32
 
 EXPORTS
-;Version 1.4.4beta04
+;Version 1.4.4beta05
   png_build_grayscale_palette  @1
 ;  png_check_sig        @2
   png_chunk_error      @3
diff --git a/scripts/pngos2.def b/scripts/pngos2.def
index d79b081..0754174 100644
--- a/scripts/pngos2.def
+++ b/scripts/pngos2.def
@@ -2,7 +2,7 @@
 ; PNG.LIB module definition file for OS/2
 ;----------------------------------------
 
-; Version 1.4.4beta04
+; Version 1.4.4beta05
 
 LIBRARY		PNG
 DESCRIPTION	"PNG image compression library for OS/2"
diff --git a/scripts/pngwin.def b/scripts/pngwin.def
index 8d87dca..144b91a 100644
--- a/scripts/pngwin.def
+++ b/scripts/pngwin.def
@@ -5,7 +5,7 @@
 LIBRARY
 
 EXPORTS
-;Version 1.4.4beta04
+;Version 1.4.4beta05
   png_build_grayscale_palette
   png_chunk_error
   png_chunk_warning
diff --git a/png.h b/png.h
index f306a8a..8c416c4 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.4.4beta04 - July 31, 2010
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *  libpng versions 0.97, January 1998, through 1.4.4beta04 - July 31, 2010: Glenn
  *  See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -145,7 +145,7 @@
  *    1.4.3beta01-05          14    10403  14.so.14.3[.0]
  *    1.4.3rc01-03            14    10403  14.so.14.3[.0]
  *    1.4.3                   14    10403  14.so.14.3[.0]
- *    1.4.4beta01-04          14    10404  14.so.14.4[.0]
+ *    1.4.4beta01-05          14    10404  14.so.14.4[.0]
  *
  *    Henceforth the source version will match the shared-library major
  *    and minor numbers; the shared-library major version number will be
@@ -177,7 +177,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.4.4beta04, July 31, 2010, are
  * Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -289,13 +289,13 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    July 31, 2010
+ *    August 3, 2010
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
  *    upward through 1.4.4beta04 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *
  *    Libpng only has three year fields.  One is a 2-byte unsigned integer
@@ -351,9 +351,9 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.4.4beta04"
+#define PNG_LIBPNG_VER_STRING "1.4.4beta05"
 #define PNG_HEADER_VERSION_STRING \
-   " libpng version 1.4.4beta04 - July 31, 2010\n"
+   " libpng version 1.4.4beta05 - August 3, 2010\n"
 
 #define PNG_LIBPNG_VER_SONUM   14
 #define PNG_LIBPNG_VER_DLLNUM  14
@@ -366,7 +366,7 @@
  * PNG_LIBPNG_VER_STRING, omitting any leading zero:
  */
 
-#define PNG_LIBPNG_VER_BUILD  04
+#define PNG_LIBPNG_VER_BUILD  05
 
 /* Release Status */
 #define PNG_LIBPNG_BUILD_ALPHA    1
@@ -1475,7 +1475,7 @@
 /* This triggers a compiler error in png.c, if png.c and png.h
  * do not agree upon the version number.
  */
-typedef png_structp version_1_4_4beta04;
+typedef png_structp version_1_4_4beta05;
 
 typedef png_struct FAR * FAR * png_structpp;
 
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.4.4beta04 - July 31, 2010
+ * libpng version 1.4.4beta05 - August 3, 2010
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *  libpng versions 0.97, January 1998, through 1.4.4beta04 - July 31, 2010: Glenn
+ *  libpng versions 0.97, January 1998, through 1.4.4beta05 - August 3, 2010: Glenn
  *  See also "Contributing Authors", below.
  *
@@ -177,7 +177,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.4.4beta04, July 31, 2010, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.4.4beta05, August 3, 2010, are
  * Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
@@ -289,13 +289,13 @@
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
- *    upward through 1.4.4beta04 are Y2K compliant.  It is my belief that earlier
+ *    upward through 1.4.4beta05 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *